# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\"0\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05login\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"<\n\x0fRegisterRequest\x12\x12\n\nuser_email\x18\x01 \x01(\t\x12\x15\n\ruser_password\x18\x02 \x01(\t\"C\n\x16ROPCAuthorizationGrant\x12\x12\n\nuser_email\x18\x01 \x01(\t\x12\x15\n\ruser_password\x18\x02 \x01(\t\"S\n\x11IssueTokenRequest\x12\'\n\x04ropc\x18\x02 \x01(\x0b\x32\x17.ROPCAuthorizationGrantH\x00\x42\x15\n\x13\x61uthorization_grant\">\n\x12IssueTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\ntoken_type\x18\x02 \x01(\t\"#\n\x12RevokeTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"F\n\x10\x41uthorizeRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any2\xf0\x01\n\rAuthorization\x12\x34\n\x08Register\x12\x10.RegisterRequest\x1a\x16.google.protobuf.Empty\x12\x35\n\nIssueToken\x12\x12.IssueTokenRequest\x1a\x13.IssueTokenResponse\x12:\n\x0bRevokeToken\x12\x13.RevokeTokenRequest\x1a\x16.google.protobuf.Empty\x12\x36\n\tAuthorize\x12\x11.AuthorizeRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USER._serialized_start=70
  _USER._serialized_end=118
  _REGISTERREQUEST._serialized_start=120
  _REGISTERREQUEST._serialized_end=180
  _ROPCAUTHORIZATIONGRANT._serialized_start=182
  _ROPCAUTHORIZATIONGRANT._serialized_end=249
  _ISSUETOKENREQUEST._serialized_start=251
  _ISSUETOKENREQUEST._serialized_end=334
  _ISSUETOKENRESPONSE._serialized_start=336
  _ISSUETOKENRESPONSE._serialized_end=398
  _REVOKETOKENREQUEST._serialized_start=400
  _REVOKETOKENREQUEST._serialized_end=435
  _AUTHORIZEREQUEST._serialized_start=437
  _AUTHORIZEREQUEST._serialized_end=507
  _AUTHORIZATION._serialized_start=510
  _AUTHORIZATION._serialized_end=750
# @@protoc_insertion_point(module_scope)
