# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rprofile.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x1d\n\nProfileKey\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\".\n\x10\x45mployeeEditable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"I\n\x08\x45mployee\x12\x18\n\x03key\x18\x01 \x01(\x0b\x32\x0b.ProfileKey\x12#\n\x08\x65\x64itable\x18\x02 \x01(\x0b\x32\x11.EmployeeEditable\".\n\x10\x45mployerEditable\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\"I\n\x08\x45mployer\x12\x18\n\x03key\x18\x01 \x01(\x0b\x32\x0b.ProfileKey\x12#\n\x08\x65\x64itable\x18\x02 \x01(\x0b\x32\x11.EmployerEditable\"\"\n\x0bPositionKey\x12\x13\n\x0bposition_id\x18\x01 \x01(\x04\"0\n\x11PositionsEditable\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"n\n\x08Position\x12\x19\n\x03key\x18\x01 \x01(\x0b\x32\x0c.PositionKey\x12!\n\x0c\x65mployer_key\x18\x02 \x01(\x0b\x32\x0b.ProfileKey\x12$\n\x08\x65\x64itable\x18\x03 \x01(\x0b\x32\x12.PositionsEditable\"`\n\x15\x43reatePositionRequest\x12!\n\x0c\x65mployer_key\x18\x01 \x01(\x0b\x32\x0b.ProfileKey\x12$\n\x08\x65\x64itable\x18\x02 \x01(\x0b\x32\x12.PositionsEditable\"\x89\x01\n\x12GetProfileResponse\x12\x1d\n\x08\x65mployee\x18\x01 \x01(\x0b\x32\t.EmployeeH\x00\x12\x1d\n\x08\x65mployer\x18\x02 \x01(\x0b\x32\t.EmployerH\x00\x12)\n\x07neither\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\n\n\x08response2\xdf\x04\n\x07Profile\x12.\n\nGetProfile\x12\x0b.ProfileKey\x1a\x13.GetProfileResponse\x12\x34\n\rDeleteProfile\x12\x0b.ProfileKey\x1a\x16.google.protobuf.Empty\x12:\n\x15\x43reateEmployeeProfile\x12\t.Employee\x1a\x16.google.protobuf.Empty\x12:\n\x15UpdateEmployeeProfile\x12\t.Employee\x1a\x16.google.protobuf.Empty\x12:\n\x15\x43reateEmployerProfile\x12\t.Employer\x1a\x16.google.protobuf.Empty\x12:\n\x15UpdateEmployerProfile\x12\t.Employer\x1a\x16.google.protobuf.Empty\x12&\n\x0bGetPosition\x12\x0c.PositionKey\x1a\t.Position\x12\x31\n\x15ListEmployerPositions\x12\x0b.ProfileKey\x1a\t.Position0\x01\x12\x36\n\x0e\x43reatePosition\x12\x16.CreatePositionRequest\x1a\x0c.PositionKey\x12\x33\n\x0eUpdatePosition\x12\t.Position\x1a\x16.google.protobuf.Empty\x12\x36\n\x0e\x44\x65letePosition\x12\x0c.PositionKey\x1a\x16.google.protobuf.Emptyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'profile_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILEKEY._serialized_start=46
  _PROFILEKEY._serialized_end=75
  _EMPLOYEEEDITABLE._serialized_start=77
  _EMPLOYEEEDITABLE._serialized_end=123
  _EMPLOYEE._serialized_start=125
  _EMPLOYEE._serialized_end=198
  _EMPLOYEREDITABLE._serialized_start=200
  _EMPLOYEREDITABLE._serialized_end=246
  _EMPLOYER._serialized_start=248
  _EMPLOYER._serialized_end=321
  _POSITIONKEY._serialized_start=323
  _POSITIONKEY._serialized_end=357
  _POSITIONSEDITABLE._serialized_start=359
  _POSITIONSEDITABLE._serialized_end=407
  _POSITION._serialized_start=409
  _POSITION._serialized_end=519
  _CREATEPOSITIONREQUEST._serialized_start=521
  _CREATEPOSITIONREQUEST._serialized_end=617
  _GETPROFILERESPONSE._serialized_start=620
  _GETPROFILERESPONSE._serialized_end=757
  _PROFILE._serialized_start=760
  _PROFILE._serialized_end=1367
# @@protoc_insertion_point(module_scope)
